@@ -51,6 +51,10 @@ class Item():
         """
         return self.__Raw
 
+    @Raw.setter
+    def Raw(self, value):
+        self.__Raw = value
+
     @property
     def Links(self):
         """Linked files
@@ -118,7 +122,7 @@ class Item():
         Returns:
             list: list of chunks of original string
         """
-        return Item(None, None, None, None)._safe_linesplit(string)
+        return Item(None, None, None, None, None)._safe_linesplit(string)
 
     def _safe_linesplit(self, string):
         return [x for x in re.split(r"\s|\t|\x1b", string) if x]
@@ -307,6 +311,10 @@ class Variable(Item):
         """
         return self.__VarValue
 
+    @VarValue.setter
+    def VarValue(self, value):
+        self.__VarValue = value
+
     @property
     def VarOp(self):
         """Variable operation
